@@ -196,7 +196,7 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -214,7 +214,7 @@ class BlockDeviceMapping:
         self,
         *,
         device_name: typing.Optional[builtins.str] = None,
-        ebs: typing.Optional[typing.Union["Ebs", typing.Dict[str, typing.Any]]] = None,
+        ebs: typing.Optional[typing.Union["Ebs", typing.Dict[builtins.str, typing.Any]]] = None,
         no_device: typing.Optional[builtins.str] = None,
         virtual_name: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -227,12 +227,12 @@ class BlockDeviceMapping:
         if isinstance(ebs, dict):
             ebs = Ebs(**ebs)
         if __debug__:
-            type_hints = typing.get_type_hints(BlockDeviceMapping.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__3fe32ebe4836a44033ebf19af753f36218f418d4e857af08a68288da907051cc)
             check_type(argname="argument device_name", value=device_name, expected_type=type_hints["device_name"])
             check_type(argname="argument ebs", value=ebs, expected_type=type_hints["ebs"])
             check_type(argname="argument no_device", value=no_device, expected_type=type_hints["no_device"])
             check_type(argname="argument virtual_name", value=virtual_name, expected_type=type_hints["virtual_name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if device_name is not None:
             self._values["device_name"] = device_name
         if ebs is not None:
@@ -275,22 +275,22 @@ class BlockDeviceMapping:
 
 
 class CreateAMI(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-create-ami.CreateAMI",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         instance_id: builtins.str,
-        block_device_mappings: typing.Optional[typing.Sequence[typing.Union[BlockDeviceMapping, typing.Dict[str, typing.Any]]]] = None,
+        block_device_mappings: typing.Optional[typing.Sequence[typing.Union[BlockDeviceMapping, typing.Dict[builtins.str, typing.Any]]]] = None,
         delete_ami: typing.Optional[builtins.bool] = None,
         delete_instance: typing.Optional[builtins.bool] = None,
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
-        tag_specifications: typing.Optional[typing.Sequence[typing.Union["TagSpecification", typing.Dict[str, typing.Any]]]] = None,
+        tag_specifications: typing.Optional[typing.Sequence[typing.Union["TagSpecification", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -304,7 +304,7 @@ class CreateAMI(
         :param tag_specifications: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CreateAMI.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0464956a0a0d750a7a0c55aeb2101de5b4f90a1fa18a8ceb1a249895543b2eb9)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CreateAMIProps(
@@ -348,12 +348,12 @@ class CreateAMIProps:
         self,
         *,
         instance_id: builtins.str,
-        block_device_mappings: typing.Optional[typing.Sequence[typing.Union[BlockDeviceMapping, typing.Dict[str, typing.Any]]]] = None,
+        block_device_mappings: typing.Optional[typing.Sequence[typing.Union[BlockDeviceMapping, typing.Dict[builtins.str, typing.Any]]]] = None,
         delete_ami: typing.Optional[builtins.bool] = None,
         delete_instance: typing.Optional[builtins.bool] = None,
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
-        tag_specifications: typing.Optional[typing.Sequence[typing.Union["TagSpecification", typing.Dict[str, typing.Any]]]] = None,
+        tag_specifications: typing.Optional[typing.Sequence[typing.Union["TagSpecification", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param instance_id: 
@@ -365,7 +365,7 @@ class CreateAMIProps:
         :param tag_specifications: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CreateAMIProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__a019e061bf5a0d0eeb277737e9661a20b9f906bb50f72d2cfb2cffaad0732e78)
             check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
             check_type(argname="argument block_device_mappings", value=block_device_mappings, expected_type=type_hints["block_device_mappings"])
             check_type(argname="argument delete_ami", value=delete_ami, expected_type=type_hints["delete_ami"])
@@ -373,7 +373,7 @@ class CreateAMIProps:
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument tag_specifications", value=tag_specifications, expected_type=type_hints["tag_specifications"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "instance_id": instance_id,
         }
         if block_device_mappings is not None:
@@ -478,7 +478,7 @@ class Ebs:
         :param volume_type: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Ebs.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__38961795a485226630199fa5c37425c3556906a6e15bbcc91a6ad3fb127acd93)
             check_type(argname="argument delete_on_termination", value=delete_on_termination, expected_type=type_hints["delete_on_termination"])
             check_type(argname="argument encrypted", value=encrypted, expected_type=type_hints["encrypted"])
             check_type(argname="argument iops", value=iops, expected_type=type_hints["iops"])
@@ -488,7 +488,7 @@ class Ebs:
             check_type(argname="argument throughput", value=throughput, expected_type=type_hints["throughput"])
             check_type(argname="argument volume_size", value=volume_size, expected_type=type_hints["volume_size"])
             check_type(argname="argument volume_type", value=volume_type, expected_type=type_hints["volume_type"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if delete_on_termination is not None:
             self._values["delete_on_termination"] = delete_on_termination
         if encrypted is not None:
@@ -581,17 +581,17 @@ class TagSpecification:
         self,
         *,
         resource_type: typing.Optional[ResourceType] = None,
-        tags: typing.Optional[typing.Sequence[typing.Union["Tags", typing.Dict[str, typing.Any]]]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union["Tags", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param resource_type: 
         :param tags: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TagSpecification.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__3fbbc5d4c9b787eadb6ec5d367f581c01fb145d0bed5a4284005f22ed70e2bd5)
             check_type(argname="argument resource_type", value=resource_type, expected_type=type_hints["resource_type"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if resource_type is not None:
             self._values["resource_type"] = resource_type
         if tags is not None:
@@ -631,10 +631,10 @@ class Tags:
         :param value: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Tags.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__732c9f882940fd1756c2566853fee5dfec8740b269a4989a410735382c52809b)
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "key": key,
             "value": value,
         }
@@ -686,3 +686,72 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__3fe32ebe4836a44033ebf19af753f36218f418d4e857af08a68288da907051cc(
+    *,
+    device_name: typing.Optional[builtins.str] = None,
+    ebs: typing.Optional[typing.Union[Ebs, typing.Dict[builtins.str, typing.Any]]] = None,
+    no_device: typing.Optional[builtins.str] = None,
+    virtual_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0464956a0a0d750a7a0c55aeb2101de5b4f90a1fa18a8ceb1a249895543b2eb9(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    instance_id: builtins.str,
+    block_device_mappings: typing.Optional[typing.Sequence[typing.Union[BlockDeviceMapping, typing.Dict[builtins.str, typing.Any]]]] = None,
+    delete_ami: typing.Optional[builtins.bool] = None,
+    delete_instance: typing.Optional[builtins.bool] = None,
+    description: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    tag_specifications: typing.Optional[typing.Sequence[typing.Union[TagSpecification, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a019e061bf5a0d0eeb277737e9661a20b9f906bb50f72d2cfb2cffaad0732e78(
+    *,
+    instance_id: builtins.str,
+    block_device_mappings: typing.Optional[typing.Sequence[typing.Union[BlockDeviceMapping, typing.Dict[builtins.str, typing.Any]]]] = None,
+    delete_ami: typing.Optional[builtins.bool] = None,
+    delete_instance: typing.Optional[builtins.bool] = None,
+    description: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    tag_specifications: typing.Optional[typing.Sequence[typing.Union[TagSpecification, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__38961795a485226630199fa5c37425c3556906a6e15bbcc91a6ad3fb127acd93(
+    *,
+    delete_on_termination: typing.Optional[builtins.bool] = None,
+    encrypted: typing.Optional[builtins.bool] = None,
+    iops: typing.Optional[jsii.Number] = None,
+    kms_key_id: typing.Optional[builtins.str] = None,
+    outpost_arn: typing.Optional[builtins.str] = None,
+    snapshot_id: typing.Optional[builtins.str] = None,
+    throughput: typing.Optional[jsii.Number] = None,
+    volume_size: typing.Optional[jsii.Number] = None,
+    volume_type: typing.Optional[VolumeType] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3fbbc5d4c9b787eadb6ec5d367f581c01fb145d0bed5a4284005f22ed70e2bd5(
+    *,
+    resource_type: typing.Optional[ResourceType] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[Tags, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__732c9f882940fd1756c2566853fee5dfec8740b269a4989a410735382c52809b(
+    *,
+    key: builtins.str,
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
